@@ -15,8 +15,8 @@
 """
 
 # Core classes
-from .core import Context, Command, MultiCommand, Group, CommandCollection, \
-     Parameter, Option, Argument
+from .core import Context, BaseCommand, Command, MultiCommand, Group, \
+     CommandCollection, Parameter, Option, Argument
 
 # Decorators
 from .decorators import pass_context, pass_obj, make_pass_decorator, \
@@ -28,7 +28,8 @@ from .types import ParamType, File, Path, Choice, IntRange, STRING, INT, \
      FLOAT, BOOL, UUID
 
 # Utilities
-from .utils import echo, get_binary_stream, get_text_stream
+from .utils import echo, get_binary_stream, get_text_stream, \
+     format_filename
 
 # Terminal functions
 from .termui import prompt, confirm, get_terminal_size, echo_via_pager
@@ -45,8 +46,8 @@ from .parser import OptionParser
 
 __all__ = [
     # Core classes
-    'Context', 'Command', 'MultiCommand', 'Group', 'CommandCollection',
-    'Parameter', 'Option', 'Argument',
+    'Context', 'BaseCommand', 'Command', 'MultiCommand', 'Group',
+    'CommandCollection', 'Parameter', 'Option', 'Argument',
 
     # Decorators
     'pass_context', 'pass_obj', 'make_pass_decorator', 'command', 'group',
@@ -58,7 +59,7 @@ __all__ = [
     'FLOAT', 'BOOL', 'UUID',
 
     # Utilities
-    'echo', 'get_binary_stream', 'get_text_stream',
+    'echo', 'get_binary_stream', 'get_text_stream', 'format_filename',
 
     # Terminal functions
     'prompt', 'confirm', 'get_terminal_size', 'echo_via_pager',
