@@ -9,7 +9,8 @@ def _make_text_stream(stream, encoding, errors):
         encoding = get_best_encoding(stream)
     if errors is None:
         errors = 'replace'
-    return _NonClosingTextIOWrapper(stream, encoding, errors)
+    return _NonClosingTextIOWrapper(stream, encoding, errors,
+                                    line_buffering=True)
 
 
 def is_ascii_encoding(encoding):
@@ -35,7 +36,10 @@ class _NonClosingTextIOWrapper(io.TextIOWrapper):
                                   encoding, errors)
 
     def __del__(self):
-        self.buffer._prevent_close = True
+        try:
+            self.detach()
+        except Exception:
+            pass
 
 
 class _FixupStream(object):
@@ -46,20 +50,15 @@ class _FixupStream(object):
 
     def __init__(self, stream):
         self._stream = stream
-        self._prevent_close = False
 
     def __getattr__(self, name):
         return getattr(self._stream, name)
 
-    def close(self):
-        if not self._prevent_close:
-            self._stream.close()
-
     def read1(self, size):
         f = getattr(self._stream, 'read1', None)
         if f is not None:
             return f(size)
-        return self._stream.readline(size)
+        return self._stream.read(size)
 
     def readable(self):
         x = getattr(self._stream, 'readable', None)
